@@ -119,16 +119,16 @@ and not simply return an error message as a result.
 
 import io
 import contextlib
+import urllib.parse
 from sys import exc_info as _exc_info
 from traceback import format_exception as _format_exception
 from xml.sax import saxutils
+import html
 
-import six
-from six.moves import urllib
+from more_itertools import always_iterable
 
 import cherrypy
-from cherrypy._cpcompat import escape_html
-from cherrypy._cpcompat import text_or_bytes, ntob
+from cherrypy._cpcompat import ntob
 from cherrypy._cpcompat import tonative
 from cherrypy._helper import classproperty
 from cherrypy.lib import httputil as _httputil
@@ -204,9 +204,6 @@ class HTTPRedirect(CherryPyException):
     """The encoding when passed urls are not native strings"""
 
     def __init__(self, urls, status=None, encoding=None):
-        if isinstance(urls, text_or_bytes):
-            urls = [urls]
-
         self.urls = abs_urls = [
             # Note that urljoin will "do the right thing" whether url is:
             #  1. a complete URL with host (e.g. "http://www.example.com/test")
@@ -217,7 +214,7 @@ class HTTPRedirect(CherryPyException):
                 cherrypy.url(),
                 tonative(url, encoding or self.encoding),
             )
-            for url in urls
+            for url in always_iterable(urls)
         ]
 
         status = (
@@ -275,7 +272,7 @@ class HTTPRedirect(CherryPyException):
             }[status]
             msg += '<a href=%s>%s</a>.'
             msgs = [
-                msg % (saxutils.quoteattr(u), escape_html(u))
+                msg % (saxutils.quoteattr(u), html.escape(u, quote=False))
                 for u in self.urls
             ]
             response.body = ntob('<br />\n'.join(msgs), 'utf-8')
@@ -497,11 +494,11 @@ def get_error_page(status, **kwargs):
     if kwargs.get('version') is None:
         kwargs['version'] = cherrypy.__version__
 
-    for k, v in six.iteritems(kwargs):
+    for k, v in kwargs.items():
         if v is None:
             kwargs[k] = ''
         else:
-            kwargs[k] = escape_html(kwargs[k])
+            kwargs[k] = html.escape(kwargs[k], quote=False)
 
     # Use a custom template or callable for the error page?
     pages = cherrypy.serving.request.error_page
@@ -521,13 +518,13 @@ def get_error_page(status, **kwargs):
                 if cherrypy.lib.is_iterator(result):
                     from cherrypy.lib.encoding import UTF8StreamEncoder
                     return UTF8StreamEncoder(result)
-                elif isinstance(result, six.text_type):
+                elif isinstance(result, str):
                     return result.encode('utf-8')
                 else:
                     if not isinstance(result, bytes):
                         raise ValueError(
                             'error page function did not '
-                            'return a bytestring, six.text_type or an '
+                            'return a bytestring, str or an '
                             'iterator - returned object of type %s.'
                             % (type(result).__name__))
                     return result
