@@ -1,18 +1,16 @@
 import sys
 import time
+from http.cookies import SimpleCookie, CookieError
 
 import uuid
 
-import six
-from six.moves.http_cookies import SimpleCookie, CookieError
-
-from more_itertools.recipes import consume
+from more_itertools import consume
 
 import cherrypy
-from cherrypy._cpcompat import text_or_bytes, ntob
+from cherrypy._cpcompat import ntob
 from cherrypy import _cpreqbody
 from cherrypy._cperror import format_exc, bare_error
-from cherrypy.lib import httputil, file_generator, reprconf
+from cherrypy.lib import httputil, reprconf, encoding
 
 
 class Hook(object):
@@ -141,8 +139,8 @@ def hooks_namespace(k, v):
     # hookpoint per path (e.g. "hooks.before_handler.1").
     # Little-known fact you only get from reading source ;)
     hookpoint = k.split('.', 1)[0]
-    if isinstance(v, text_or_bytes):
-        v = cherrypy.lib.attributes(v)
+    if isinstance(v, str):
+        v = cherrypy.lib.reprconf.attributes(v)
     if not isinstance(v, Hook):
         v = Hook(v)
     cherrypy.serving.request.hooks[hookpoint].append(v)
@@ -704,12 +702,6 @@ class Request(object):
                 'strings for this resource must be encoded with %r.' %
                 self.query_string_encoding)
 
-        # Python 2 only: keyword arguments must be byte strings (type 'str').
-        if six.PY2:
-            for key, value in p.items():
-                if isinstance(key, six.text_type):
-                    del p[key]
-                    p[key.encode(self.query_string_encoding)] = value
         self.params.update(p)
 
     def process_headers(self):
@@ -774,9 +766,8 @@ class ResponseBody(object):
 
     """The body of the HTTP response (the response entity)."""
 
-    if six.PY3:
-        unicode_err = ('Page handlers MUST return bytes. Use tools.encode '
-                       'if you wish to return unicode.')
+    unicode_err = ('Page handlers MUST return bytes. Use tools.encode '
+                   'if you wish to return unicode.')
 
     def __get__(self, obj, objclass=None):
         if obj is None:
@@ -787,30 +778,14 @@ class ResponseBody(object):
 
     def __set__(self, obj, value):
         # Convert the given value to an iterable object.
-        if six.PY3 and isinstance(value, str):
+        if isinstance(value, str):
             raise ValueError(self.unicode_err)
-
-        if isinstance(value, text_or_bytes):
-            # strings get wrapped in a list because iterating over a single
-            # item list is much faster than iterating over every character
-            # in a long string.
-            if value:
-                value = [value]
-            else:
-                # [''] doesn't evaluate to False, so replace it with [].
-                value = []
-        elif six.PY3 and isinstance(value, list):
+        elif isinstance(value, list):
             # every item in a list must be bytes...
-            for i, item in enumerate(value):
-                if isinstance(item, str):
-                    raise ValueError(self.unicode_err)
-        # Don't use isinstance here; io.IOBase which has an ABC takes
-        # 1000 times as long as, say, isinstance(value, str)
-        elif hasattr(value, 'read'):
-            value = file_generator(value)
-        elif value is None:
-            value = []
-        obj._body = value
+            if any(isinstance(item, str) for item in value):
+                raise ValueError(self.unicode_err)
+
+        obj._body = encoding.prepare_iter(value)
 
 
 class Response(object):
@@ -868,19 +843,9 @@ class Response(object):
 
     def collapse_body(self):
         """Collapse self.body to a single string; replace it and return it."""
-        if isinstance(self.body, text_or_bytes):
-            return self.body
-
-        newbody = []
-        for chunk in self.body:
-            if six.PY3 and not isinstance(chunk, bytes):
-                raise TypeError("Chunk %s is not of type 'bytes'." %
-                                repr(chunk))
-            newbody.append(chunk)
-        newbody = b''.join(newbody)
-
-        self.body = newbody
-        return newbody
+        new_body = b''.join(self.body)
+        self.body = new_body
+        return new_body
 
     def _flush_body(self):
         """
@@ -930,9 +895,9 @@ class Response(object):
         if cookie:
             for line in cookie.split('\r\n'):
                 name, value = line.split(': ', 1)
-                if isinstance(name, six.text_type):
+                if isinstance(name, str):
                     name = name.encode('ISO-8859-1')
-                if isinstance(value, six.text_type):
+                if isinstance(value, str):
                     value = headers.encode(value)
                 h.append((name, value))
 
