@@ -18,32 +18,12 @@ by adding a named handler to Config.namespaces. The name can be any string,
 and the handler must be either a callable or a context manager.
 """
 
-from cherrypy._cpcompat import text_or_bytes
-
-try:
-    # Python 3.0+
-    from configparser import ConfigParser
-except ImportError:
-    from ConfigParser import ConfigParser
-
-try:
-    text_or_bytes
-except NameError:
-    text_or_bytes = str
-
-import operator as _operator
+import configparser
+import builtins
+import operator
 import sys
 
-from six.moves import builtins
-
-
-def as_dict(config):
-    """Return a dict from 'config' whether it is a dict, file, or filename."""
-    if isinstance(config, text_or_bytes):
-        config = Parser().dict_from_file(config)
-    elif hasattr(config, 'read'):
-        config = Parser().dict_from_file(config)
-    return config
+from cherrypy._cpcompat import text_or_bytes
 
 
 class NamespaceSet(dict):
@@ -82,9 +62,9 @@ class NamespaceSet(dict):
 
         # I chose __enter__ and __exit__ so someday this could be
         # rewritten using Python 2.5's 'with' statement:
-        # for ns, handler in six.iteritems(self):
+        # for ns, handler in self.items():
         #     with handler as callable:
-        #         for k, v in six.iteritems(ns_confs.get(ns, {})):
+        #         for k, v in ns_confs.get(ns, {}).items():
         #             callable(k, v)
         for ns, handler in self.items():
             exit = getattr(handler, '__exit__', None)
@@ -146,16 +126,8 @@ class Config(dict):
         dict.update(self, self.defaults)
 
     def update(self, config):
-        """Update self from a dict, file or filename."""
-        if isinstance(config, text_or_bytes):
-            # Filename
-            config = Parser().dict_from_file(config)
-        elif hasattr(config, 'read'):
-            # Open file object
-            config = Parser().dict_from_file(config)
-        else:
-            config = config.copy()
-        self._apply(config)
+        """Update self from a dict, file, or filename."""
+        self._apply(Parser.load(config))
 
     def _apply(self, config):
         """Update self from a dict."""
@@ -174,7 +146,7 @@ class Config(dict):
         self.namespaces({k: v})
 
 
-class Parser(ConfigParser):
+class Parser(configparser.ConfigParser):
 
     """Sub-class of ConfigParser that keeps the case of options and that
     raises an exception if the file cannot be read.
@@ -224,6 +196,17 @@ class Parser(ConfigParser):
             self.read(file)
         return self.as_dict()
 
+    @classmethod
+    def load(self, input):
+        """Resolve 'input' to dict from a dict, file, or filename."""
+        is_file = (
+            # Filename
+            isinstance(input, text_or_bytes)
+            # Open file object
+            or hasattr(input, 'read')
+        )
+        return Parser().dict_from_file(input) if is_file else input.copy()
+
 
 # public domain "unrepr" implementation, found on the web and then improved.
 
@@ -477,13 +460,13 @@ class _Builder3:
         return op(left, right)
 
     def build_Add(self, o):
-        return _operator.add
+        return operator.add
 
     def build_Mult(self, o):
-        return _operator.mul
+        return operator.mul
 
     def build_USub(self, o):
-        return _operator.neg
+        return operator.neg
 
     def build_Attribute(self, o):
         parent = self.build(o.value)
