@@ -81,8 +81,6 @@ import warnings
 import subprocess
 import functools
 
-import six
-
 
 # Here I save the value of os.getcwd(), which, if I am imported early enough,
 # will be the directory from which the startup script was run.  This is needed
@@ -249,7 +247,7 @@ class Bus(object):
         return output
 
     def _clean_exit(self):
-        """An atexit handler which asserts the Bus is not running."""
+        """Assert that the Bus is not running in atexit handler callback."""
         if self.state != states.EXITING:
             warnings.warn(
                 'The main thread is exiting, but the Bus is in the %r state; '
@@ -375,23 +373,9 @@ class Bus(object):
         else:
             states = [state]
 
-        def _wait():
-            while self.state not in states:
-                time.sleep(interval)
-                self.publish(channel)
-
-        # From http://psyco.sourceforge.net/psycoguide/bugs.html:
-        # "The compiled machine code does not include the regular polling
-        # done by Python, meaning that a KeyboardInterrupt will not be
-        # detected before execution comes back to the regular Python
-        # interpreter. Your program cannot be interrupted if caught
-        # into an infinite Psyco-compiled loop."
-        try:
-            sys.modules['psyco'].cannotcompile(_wait)
-        except (KeyError, AttributeError):
-            pass
-
-        _wait()
+        while self.state not in states:
+            time.sleep(interval)
+            self.publish(channel)
 
     def _do_execv(self):
         """Re-execute the current process.
@@ -450,7 +434,7 @@ class Bus(object):
         :seealso: http://stackoverflow.com/a/28414807/595220
         """
         try:
-            char_p = ctypes.c_char_p if six.PY2 else ctypes.c_wchar_p
+            char_p = ctypes.c_wchar_p
 
             argv = ctypes.POINTER(char_p)()
             argc = ctypes.c_int()
@@ -483,7 +467,7 @@ class Bus(object):
 
             try:
                 c_ind = _argv.index('-c')
-                if m_ind < argv_len - 1 and _argv[c_ind + 1] == '-c':
+                if c_ind < argv_len - 1 and _argv[c_ind + 1] == '-c':
                     is_command = True
             except (IndexError, ValueError):
                 c_ind = None
