@@ -2,20 +2,21 @@ import os
 import threading
 import time
 import socket
+from http.client import HTTPConnection
 
 import pytest
+from path import Path
+from more_itertools import consume
 
 import cherrypy
-from cherrypy._cpcompat import (
-    copykeys, json_decode,
-    HTTPConnection, HTTPSConnection
-)
+from cherrypy._cpcompat import HTTPSConnection
 from cherrypy.lib import sessions
 from cherrypy.lib import reprconf
 from cherrypy.lib.httputil import response_codes
 from cherrypy.test import helper
+from cherrypy import _json as json
 
-localDir = os.path.dirname(__file__)
+localDir = Path(__file__).dirname()
 
 
 def http_methods_allowed(methods=['GET', 'HEAD']):
@@ -24,6 +25,7 @@ def http_methods_allowed(methods=['GET', 'HEAD']):
         cherrypy.response.headers['Allow'] = ', '.join(methods)
         raise cherrypy.HTTPError(405)
 
+
 cherrypy.tools.allow = cherrypy.Tool('on_start_resource', http_methods_allowed)
 
 
@@ -137,11 +139,17 @@ def setup_server():
 class SessionTest(helper.CPWebCase):
     setup_server = staticmethod(setup_server)
 
-    def tearDown(self):
-        # Clean up sessions.
-        for fname in os.listdir(localDir):
-            if fname.startswith(sessions.FileSession.SESSION_PREFIX):
-                os.unlink(os.path.join(localDir, fname))
+    @classmethod
+    def teardown_class(cls):
+        """Clean up sessions."""
+        super(cls, cls).teardown_class()
+        consume(
+            file.remove_p()
+            for file in localDir.listdir()
+            if file.basename().startswith(
+                sessions.FileSession.SESSION_PREFIX
+            )
+        )
 
     @pytest.mark.xfail(reason='#1534')
     def test_0_Session(self):
@@ -168,7 +176,7 @@ class SessionTest(helper.CPWebCase):
         self.getPage('/testStr', self.cookies)
         self.assertBody('3')
         self.getPage('/data', self.cookies)
-        self.assertDictEqual(json_decode(self.body),
+        self.assertDictEqual(json.decode(self.body),
                              {'counter': 3, 'aha': 'foo'})
         self.getPage('/length', self.cookies)
         self.assertBody('2')
@@ -207,14 +215,17 @@ class SessionTest(helper.CPWebCase):
         self.assertBody('done')
         self.getPage('/delete', cookieset1)
         self.assertBody('done')
-        f = lambda: [
-            x for x in os.listdir(localDir) if x.startswith('session-')]
+
+        def f():
+            return [
+                x
+                for x in os.listdir(localDir)
+                if x.startswith('session-')
+            ]
         self.assertEqual(f(), [])
 
         # Wait for the cleanup thread to delete remaining session files
         self.getPage('/')
-        f = lambda: [
-            x for x in os.listdir(localDir) if x.startswith('session-')]
         self.assertNotEqual(f(), [])
         time.sleep(2)
         self.assertEqual(f(), [])
@@ -257,7 +268,7 @@ class SessionTest(helper.CPWebCase):
                 else:
                     data_dict[index] = max(data_dict[index], int(body))
                 # Uncomment the following line to prove threads overlap.
-##                sys.stdout.write("%d " % index)
+                # sys.stdout.write("%d " % index)
 
         # Start <request_count> requests from each of
         # <client_thread_count> concurrent clients
@@ -284,7 +295,6 @@ class SessionTest(helper.CPWebCase):
         self.getPage('/iredir', self.cookies)
         self.assertBody('FileSession')
 
-    @pytest.mark.xfail(reason='#1540')
     def test_4_File_deletion(self):
         # Start a new session
         self.getPage('/testStr')
@@ -337,7 +347,7 @@ class SessionTest(helper.CPWebCase):
         # Assert there is no 'expires' param
         self.assertEqual(set(cookie_parts.keys()), set(['temp', 'Path']))
         id1 = cookie_parts['temp']
-        self.assertEqual(copykeys(sessions.RamSession.cache), [id1])
+        self.assertEqual(list(sessions.RamSession.cache), [id1])
 
         # Send another request in the same "browser session".
         self.getPage('/session_cookie', self.cookies)
@@ -346,7 +356,7 @@ class SessionTest(helper.CPWebCase):
         # Assert there is no 'expires' param
         self.assertEqual(set(cookie_parts.keys()), set(['temp', 'Path']))
         self.assertBody(id1)
-        self.assertEqual(copykeys(sessions.RamSession.cache), [id1])
+        self.assertEqual(list(sessions.RamSession.cache), [id1])
 
         # Simulate a browser close by just not sending the cookies
         self.getPage('/session_cookie')
@@ -363,7 +373,7 @@ class SessionTest(helper.CPWebCase):
 
         # Wait for the session.timeout on both sessions
         time.sleep(2.5)
-        cache = copykeys(sessions.RamSession.cache)
+        cache = list(sessions.RamSession.cache)
         if cache:
             if cache == [id2]:
                 self.fail('The second session did not time out.')
@@ -385,13 +395,12 @@ class SessionTest(helper.CPWebCase):
         assert len(sessions.RamSession.locks) == 1, 'Lock not acquired'
         s2 = sessions.RamSession()
         s2.clean_up()
-        assert len(sessions.RamSession.locks) == 1, 'Clean up should not remove active lock'
+        msg = 'Clean up should not remove active lock'
+        assert len(sessions.RamSession.locks) == 1, msg
         t.join()
 
 
-try:
-    import memcache  # NOQA
-
+def is_memcached_available():
     host, port = '127.0.0.1', 11211
     for res in socket.getaddrinfo(host, port, socket.AF_UNSPEC,
                                   socket.SOCK_STREAM):
@@ -404,100 +413,103 @@ try:
             s.settimeout(1.0)
             s.connect((host, port))
             s.close()
+            return True
         except socket.error:
             if s:
                 s.close()
-            raise
-        break
-except (ImportError, socket.error):
-    class MemcachedSessionTest(helper.CPWebCase):
-        setup_server = staticmethod(setup_server)
 
-        def test(self):
-            return self.skip('memcached not reachable ')
-else:
-    class MemcachedSessionTest(helper.CPWebCase):
-        setup_server = staticmethod(setup_server)
+    return False
 
-        def test_0_Session(self):
-            self.getPage('/set_session_cls/cherrypy.Sessions.MemcachedSession')
 
-            self.getPage('/testStr')
-            self.assertBody('1')
-            self.getPage('/testGen', self.cookies)
-            self.assertBody('2')
-            self.getPage('/testStr', self.cookies)
-            self.assertBody('3')
-            self.getPage('/length', self.cookies)
-            self.assertErrorPage(500)
-            self.assertInBody('NotImplementedError')
-            self.getPage('/delkey?key=counter', self.cookies)
-            self.assertStatus(200)
+@pytest.mark.skipif(
+    not is_memcached_available(),
+    reason='memcached not reachable',
+)
+@pytest.mark.importorskip('memcache')
+class MemcachedSessionTest(helper.CPWebCase):
+    setup_server = staticmethod(setup_server)
 
-            # Wait for the session.timeout (1 second)
-            time.sleep(1.25)
-            self.getPage('/')
-            self.assertBody('1')
+    def test_0_Session(self):
+        self.getPage(
+            '/set_session_cls/cherrypy.lib.sessions.MemcachedSession'
+        )
 
-            # Test session __contains__
-            self.getPage('/keyin?key=counter', self.cookies)
-            self.assertBody('True')
+        self.getPage('/testStr')
+        self.assertBody('1')
+        self.getPage('/testGen', self.cookies)
+        self.assertBody('2')
+        self.getPage('/testStr', self.cookies)
+        self.assertBody('3')
+        self.getPage('/length', self.cookies)
+        self.assertErrorPage(500)
+        self.assertInBody('NotImplementedError')
+        self.getPage('/delkey?key=counter', self.cookies)
+        self.assertStatus(200)
 
-            # Test session delete
-            self.getPage('/delete', self.cookies)
-            self.assertBody('done')
+        # Wait for the session.timeout (1 second)
+        time.sleep(1.25)
+        self.getPage('/')
+        self.assertBody('1')
 
-        def test_1_Concurrency(self):
-            client_thread_count = 5
-            request_count = 30
+        # Test session __contains__
+        self.getPage('/keyin?key=counter', self.cookies)
+        self.assertBody('True')
 
-            # Get initial cookie
-            self.getPage('/')
-            self.assertBody('1')
-            cookies = self.cookies
+        # Test session delete
+        self.getPage('/delete', self.cookies)
+        self.assertBody('done')
 
-            data_dict = {}
+    def test_1_Concurrency(self):
+        client_thread_count = 5
+        request_count = 30
 
-            def request(index):
-                for i in range(request_count):
-                    self.getPage('/', cookies)
-                    # Uncomment the following line to prove threads overlap.
-##                    sys.stdout.write("%d " % index)
-                if not self.body.isdigit():
-                    self.fail(self.body)
-                data_dict[index] = int(self.body)
+        # Get initial cookie
+        self.getPage('/')
+        self.assertBody('1')
+        cookies = self.cookies
 
-            # Start <request_count> concurrent requests from
-            # each of <client_thread_count> clients
-            ts = []
-            for c in range(client_thread_count):
-                data_dict[c] = 0
-                t = threading.Thread(target=request, args=(c,))
-                ts.append(t)
-                t.start()
+        data_dict = {}
 
-            for t in ts:
-                t.join()
+        def request(index):
+            for i in range(request_count):
+                self.getPage('/', cookies)
+                # Uncomment the following line to prove threads overlap.
+                # sys.stdout.write("%d " % index)
+            if not self.body.isdigit():
+                self.fail(self.body)
+            data_dict[index] = int(self.body)
 
-            hitcount = max(data_dict.values())
-            expected = 1 + (client_thread_count * request_count)
-            self.assertEqual(hitcount, expected)
+        # Start <request_count> concurrent requests from
+        # each of <client_thread_count> clients
+        ts = []
+        for c in range(client_thread_count):
+            data_dict[c] = 0
+            t = threading.Thread(target=request, args=(c,))
+            ts.append(t)
+            t.start()
 
-        def test_3_Redirect(self):
-            # Start a new session
-            self.getPage('/testStr')
-            self.getPage('/iredir', self.cookies)
-            self.assertBody('memcached')
+        for t in ts:
+            t.join()
 
-        def test_5_Error_paths(self):
-            self.getPage('/unknown/page')
-            self.assertErrorPage(
-                404, "The path '/unknown/page' was not found.")
+        hitcount = max(data_dict.values())
+        expected = 1 + (client_thread_count * request_count)
+        self.assertEqual(hitcount, expected)
 
-            # Note: this path is *not* the same as above. The above
-            # takes a normal route through the session code; this one
-            # skips the session code's before_handler and only calls
-            # before_finalize (save) and on_end (close). So the session
-            # code has to survive calling save/close without init.
-            self.getPage('/restricted', self.cookies, method='POST')
-            self.assertErrorPage(405, response_codes[405][1])
+    def test_3_Redirect(self):
+        # Start a new session
+        self.getPage('/testStr')
+        self.getPage('/iredir', self.cookies)
+        self.assertBody('MemcachedSession')
+
+    def test_5_Error_paths(self):
+        self.getPage('/unknown/page')
+        self.assertErrorPage(
+            404, "The path '/unknown/page' was not found.")
+
+        # Note: this path is *not* the same as above. The above
+        # takes a normal route through the session code; this one
+        # skips the session code's before_handler and only calls
+        # before_finalize (save) and on_end (close). So the session
+        # code has to survive calling save/close without init.
+        self.getPage('/restricted', self.cookies, method='POST')
+        self.assertErrorPage(405, response_codes[405][1])
