@@ -1,22 +1,19 @@
 # -*- coding: utf-8 -*-
-import contextlib
 import io
 import os
 import sys
 import platform
 import tempfile
-
-from six import text_type as str
-from six.moves import urllib
+import urllib.parse
+from http.client import HTTPConnection
 
 import pytest
 import py.path
+import path
 
 import cherrypy
 from cherrypy.lib import static
-from cherrypy._cpcompat import (
-    HTTPConnection, HTTPSConnection, ntou, tonative,
-)
+from cherrypy._cpcompat import HTTPSConnection, ntou, tonative
 from cherrypy.test import helper
 
 
@@ -43,9 +40,9 @@ def ensure_unicode_filesystem():
         tmpdir.remove()
 
 
-curdir = os.path.join(os.getcwd(), os.path.dirname(__file__))
-has_space_filepath = os.path.join(curdir, 'static', 'has space.html')
-bigfile_filepath = os.path.join(curdir, 'static', 'bigfile.log')
+curdir = path.Path(__file__).dirname()
+has_space_filepath = curdir / 'static' / 'has space.html'
+bigfile_filepath = curdir / 'static' / 'bigfile.log'
 
 # The file size needs to be big enough such that half the size of it
 # won't be socket-buffered (or server-buffered) all in one go. See
@@ -55,6 +52,7 @@ BIGFILE_SIZE = 32 * MB
 
 
 class StaticTest(helper.CPWebCase):
+    files_to_remove = []
 
     @staticmethod
     def setup_server():
@@ -112,6 +110,10 @@ class StaticTest(helper.CPWebCase):
                 'tools.staticdir.dir': 'static',
                 'tools.staticdir.root': curdir,
             },
+            '/static-long': {
+                'tools.staticdir.on': True,
+                'tools.staticdir.dir': r'\\?\%s' % curdir,
+            },
             '/style.css': {
                 'tools.staticfile.on': True,
                 'tools.staticfile.filename': os.path.join(curdir, 'style.css'),
@@ -150,14 +152,13 @@ class StaticTest(helper.CPWebCase):
         vhost = cherrypy._cpwsgi.VirtualHost(rootApp, {'virt.net': testApp})
         cherrypy.tree.graft(vhost)
 
-    @staticmethod
-    def teardown_server():
-        for f in (has_space_filepath, bigfile_filepath):
-            if os.path.exists(f):
-                try:
-                    os.unlink(f)
-                except:
-                    pass
+    @classmethod
+    def teardown_class(cls):
+        super(cls, cls).teardown_class()
+        files_to_remove = has_space_filepath, bigfile_filepath
+        files_to_remove += tuple(cls.files_to_remove)
+        for f in files_to_remove:
+            f.remove_p()
 
     def test_static(self):
         self.getPage('/static/index.html')
@@ -186,6 +187,15 @@ class StaticTest(helper.CPWebCase):
         #   we just check the content
         self.assertMatchesBody('^Dummy stylesheet')
 
+    @pytest.mark.skipif(platform.system() != 'Windows', reason='Windows only')
+    def test_static_longpath(self):
+        """Test serving of a file in subdir of a Windows long-path
+        staticdir."""
+        self.getPage('/static-long/static/index.html')
+        self.assertStatus('200 OK')
+        self.assertHeader('Content-Type', 'text/html')
+        self.assertBody('Hello, world\r\n')
+
     def test_fallthrough(self):
         # Test that NotFound will then try dynamic handlers (see [878]).
         self.getPage('/static/dynamic')
@@ -207,8 +217,11 @@ class StaticTest(helper.CPWebCase):
         self.getPage('/docroot')
         self.assertStatus(301)
         self.assertHeader('Location', '%s/docroot/' % self.base())
-        self.assertMatchesBody("This resource .* <a href=(['\"])%s/docroot/\\1>"
-                               '%s/docroot/</a>.' % (self.base(), self.base()))
+        self.assertMatchesBody(
+            "This resource .* <a href=(['\"])%s/docroot/\\1>"
+            '%s/docroot/</a>.'
+            % (self.base(), self.base())
+        )
 
     def test_config_errors(self):
         # Check that we get an error if no .file or .dir
@@ -216,13 +229,13 @@ class StaticTest(helper.CPWebCase):
         self.assertErrorPage(500)
         if sys.version_info >= (3, 3):
             errmsg = (
-                'TypeError: staticdir\(\) missing 2 '
+                r'TypeError: staticdir\(\) missing 2 '
                 'required positional arguments'
             )
         else:
             errmsg = (
-                'TypeError: staticdir\(\) takes at least 2 '
-                '(positional )?arguments \(0 given\)'
+                r'TypeError: staticdir\(\) takes at least 2 '
+                r'(positional )?arguments \(0 given\)'
             )
         self.assertMatchesBody(errmsg.encode('ascii'))
 
@@ -384,34 +397,25 @@ class StaticTest(helper.CPWebCase):
         self.getPage('/static/\x00')
         self.assertStatus('404 Not Found')
 
-    @staticmethod
-    @contextlib.contextmanager
-    def unicode_file():
+    @classmethod
+    def unicode_file(cls):
         filename = ntou('Слава Україні.html', 'utf-8')
-        filepath = os.path.join(curdir, 'static', filename)
-        with io.open(filepath, 'w', encoding='utf-8') as strm:
+        filepath = curdir / 'static' / filename
+        with filepath.open('w', encoding='utf-8')as strm:
             strm.write(ntou('Героям Слава!', 'utf-8'))
-        try:
-            yield
-        finally:
-            os.remove(filepath)
+        cls.files_to_remove.append(filepath)
 
-    py27_on_windows = (
-        platform.system() == 'Windows' and
-        sys.version_info < (3,)
-    )
-    @pytest.mark.xfail(py27_on_windows, reason='#1544')  # noqa: E301
     def test_unicode(self):
         ensure_unicode_filesystem()
-        with self.unicode_file():
-            url = ntou('/static/Слава Україні.html', 'utf-8')
-            # quote function requires str
-            url = tonative(url, 'utf-8')
-            url = urllib.parse.quote(url)
-            self.getPage(url)
+        self.unicode_file()
+        url = ntou('/static/Слава Україні.html', 'utf-8')
+        # quote function requires str
+        url = tonative(url, 'utf-8')
+        url = urllib.parse.quote(url)
+        self.getPage(url)
 
-            expected = ntou('Героям Слава!', 'utf-8')
-            self.assertInBody(expected)
+        expected = ntou('Героям Слава!', 'utf-8')
+        self.assertInBody(expected)
 
 
 def error_page_404(status, message, traceback, version):
